@@ -2,6 +2,7 @@ from plone.app.search.browser import Search
 from Products.Five import BrowserView
 from plone.app.layout.viewlets.common import FooterViewlet
 from plone.app.layout.viewlets.common import ViewletBase
+from plone.app.layout.viewlets.common import SiteActionsViewlet
 from Products.Five.browser.pagetemplatefile import ViewPageTemplateFile
 from AccessControl import getSecurityManager
 from zope.interface import implements
@@ -554,7 +555,13 @@ class Footer(FooterViewlet):
             return False
         else:
             return True
-        
+ 
+class SiteActions(SiteActionsViewlet):
+    """
+    Site actions view stub
+    """
+    
+       
 class TitleViewlet(ViewletBase):
     """
     Changing the title format
